aair	http://xmlns.notu.be/aair#	20111028
aapi	http://rdf.alchemyapi.com/rdf/v1/s/aapi-schema#	20111028
abc	http://www.metadata.net/harmony/ABCSchemaV5Commented.rdf#	20111028
ac	http://umbel.org/umbel/ac/	20111028
acc	http://purl.org/NET/acc#	20111028
acl	http://www.w3.org/ns/auth/acl#	20111028
acm	http://www.rkbexplorer.com/ontologies/acm#	20111028
act	http://www.w3.org/2007/rif-builtin-action#	20111028
ad	http://schemas.talis.com/2005/address/schema#	20111028
address	http://schemas.talis.com/2005/address/schema#	20111028
admin	http://webns.net/mvcb/	20111028
admingeo	http://data.ordnancesurvey.co.uk/ontology/admingeo/	20111028
af	http://purl.org/ontology/af/	20111028
affy	http://www.affymetrix.com/community/publications/affymetrix/tmsplice#	20111028
afn	http://jena.hpl.hp.com/ARQ/function#	20111028
agent	http://eulersharp.sourceforge.net/2003/03swap/agent#	20111028
agents	http://eulersharp.sourceforge.net/2003/03swap/agent#	20111028
agetec	http://www.agetec.org/	20111028
aifb	http://www.aifb.kit.edu/id/	20111028
aiiso	http://purl.org/vocab/aiiso/schema#	20111028
aims	http://aims.fao.org/aos/common/	20111028
air	http://dig.csail.mit.edu/TAMI/2007/amord/air#	20111028
airport	http://www.daml.org/2001/10/html/airport-ont#	20111028
akt	http://www.aktors.org/ontology/portal#	20111028
akts	http://www.aktors.org/ontology/support#	20111028
am	http://vocab.deri.ie/am#	20111028
anca	http://users.utcluj.ro/~raluca/rdf_ontologies_ralu/ralu_modified_ontology_pizzas2_0#	20111028
aneo	http://akonadi-project.org/ontologies/aneo#	20111028
ann	http://www.w3.org/2000/10/annotation-ns#	20111028
ao	http://purl.org/ontology/ao/core#	20111028
arch	http://purl.org/archival/vocab/arch#	20111028
artstor	http://simile.mit.edu/2003/10/ontologies/artstor#	20111028
ass	http://uptheasset.org/ontology#	20111028
atom	http://www.w3.org/2005/Atom/	20111028
atomix	http://buzzword.org.uk/rdf/atomix#	20111028
atomowl	http://bblfish.net/work/atom-owl/2006-06-06/#	20111028
audio	http://purl.org/media/audio#	20111028
awol	http://bblfish.net/work/atom-owl/2006-06-06/#	20111028
b2rpubchem	http://bio2rdf.org/ns/ns/ns/pubchem#	20111028
bcnbio	http://datos.bcn.cl/ontologies/bcn-biographies#	20111028
bcncon	http://datos.bcn.cl/ontologies/bcn-congress#	20111028
bcngeo	http://datos.bcn.cl/ontologies/bcn-geographics#	20111028
bcnnorms	http://datos.bcn.cl/ontologies/bcn-norms#	20111028
bib	http://zeitkunst.org/bibtex/0.1/bibtex.owl#	20111028
biblio	http://purl.org/net/biblio#	20111028
bibo	http://purl.org/ontology/bibo/	20111028
bibtex	http://purl.oclc.org/NET/nknouf/ns/bibtex#	20111028
bill	http://www.rdfabout.com/rdf/schema/usbill/	20111028
bio	http://purl.org/vocab/bio/0.1/	20111028
bio2rdf	http://bio2rdf.org/	20111028
biocore	http://bio2rdf.org/core:	20111028
biol	http://purl.org/NET/biol/ns#	20111028
biordf	http://purl.org/net/biordfmicroarray/ns#	20111028
bioskos	http://eulersharp.sourceforge.net/2003/03swap/bioSKOSSchemes#	20111028
blt	http://data.bl.uk/schema/bibliographic#	20111028
book	http://purl.org/NET/book/vocab#	20111028
bookmark	http://www.w3.org/2002/01/bookmark#	20111028
botany	http://purl.org/NET/biol/botany#	20111028
bsbm	http://www4.wiwiss.fu-berlin.de/bizer/bsbm/v01/vocabulary/	20111028
c4dm	http://purl.org/NET/c4dm/event.owl#	20111028
c4n	http://vocab.deri.ie/c4n#	20111028
c4o	http://purl.org/spar/c4o/	20111028
cal	http://www.w3.org/2002/12/cal/ical#	20111028
campsite	http://www.openlinksw.com/campsites/schema#	20111028
card	http://www.ashutosh.com/test/	20111028
care	http://eulersharp.sourceforge.net/2003/03swap/care#	20111028
cbase	http://ontologycentral.com/2010/05/cb/vocab#	20111028
cc	http://creativecommons.org/ns#	20111028
ccard	http://purl.org/commerce/creditcard#	20111028
cco	http://purl.org/ontology/cco/core#	20111028
ccom	http://purl.org/ontology/cco/mappings#	20111028
cdm	http://purl.org/twc/ontology/cdm.owl#	20111028
ceo	http://www.ebusiness-unibw.org/ontologies/consumerelectronics/v1#	20111028
cert	http://www.w3.org/ns/auth/cert#	20111028
cfp	http://sw.deri.org/2005/08/conf/cfp.owl#	20111028
chebi	http://bio2rdf.org/chebi:	20111028
chord	http://purl.org/ontology/chord/	20111028
cito	http://purl.org/net/cito/	20111028
cld	http://purl.org/cld/terms/	20111028
climb	http://climb.dataincubator.org/vocabs/climb/	20111028
clineva	http://www.agfa.com/w3c/2009/clinicalEvaluation#	20111028
clinproc	http://www.agfa.com/w3c/2009/clinicalProcedure#	20111028
cmo	http://purl.org/twc/ontologies/cmo.owl#	20111028
cmp	http://www.ontologydesignpatterns.org/cp/owl/componency.owl#	20111028
cnt	http://www.w3.org/2008/content#	20111028
co	http://purl.org/ontology/co/core#	20111028
code	http://telegraphis.net/ontology/measurement/code#	20111028
coeus	http://bioinformatics.ua.pt/coeus/	20111028
coin	http://purl.org/court/def/2009/coin#	20111028
com	http://purl.org/commerce#	20111028
commerce	http://purl.org/commerce#	20111028
common	http://www.w3.org/2007/uwa/context/common.owl#	20111028
commons	http://commons.psi.enakting.org/def/	20111028
compass	http://purl.org/net/compass#	20111028
con	http://www.w3.org/2000/10/swap/pim/contact#	20111028
conserv	http://conserv.deri.ie/ontology#	20111028
contact	http://www.w3.org/2000/10/swap/pim/contact#	20111028
content	http://purl.org/rss/1.0/modules/content/	20111028
conv	http://purl.org/twc/vocab/conversion/	20111028
conversion	http://purl.org/twc/vocab/conversion/	20111028
coo	http://purl.org/coo/ns#	20111028
copyright	http://rhizomik.net/ontologies/2008/05/copyrightonto.owl#	20111028
cordis	http://www4.wiwiss.fu-berlin.de/cordis/resource/cordis/	20111028
core	http://vivoweb.org/ontology/core#	20111028
coref	http://www.rkbexplorer.com/ontologies/coref#	20111028
cos	http://www.inria.fr/acacia/corese#	20111028
countries	http://eulersharp.sourceforge.net/2003/03swap/countries#	20111028
courseware	http://courseware.rkbexplorer.com/ontologies/courseware#	20111028
cpm	http://catalogus-professorum.org/cpm/	20111028
cpv	http://purl.org/weso/cpv/	20111028
crm	http://purl.org/NET/cidoc-crm/core#	20111028
crypto	http://www.w3.org/2000/10/swap/crypto#	20111028
cs	http://purl.org/vocab/changeset/schema#	20111028
ct	http://data.linkedct.org/resource/linkedct/	20111028
ctag	http://commontag.org/ns#	20111028
cube	http://purl.org/linked-data/cube#	20111028
custom	http://www.openrdf.org/config/sail/custom#	20111028
cv	http://rdfs.org/resume-rdf/	20111028
cvbase	http://purl.org/captsolo/resume-rdf/0.2/base#	20111028
cyc	http://sw.opencyc.org/concept/	20111028
cycann	http://sw.cyc.com/CycAnnotations_v1#	20111028
d2rq	http://www.wiwiss.fu-berlin.de/suhl/bizer/D2RQ/0.1#	20111028
dady	http://purl.org/NET/dady#	20111028
daia	http://purl.org/ontology/daia/	20111028
dailymed	http://www4.wiwiss.fu-berlin.de/dailymed/resource/dailymed/	20111028
daml	http://www.daml.org/2001/03/daml+oil#	20111028
dawgt	http://www.w3.org/2001/sw/DataAccess/tests/test-dawg#	20111028
days	http://ontologi.es/days#	20111028
dayta	http://dayta.me/resource#	20111028
dblp	http://www4.wiwiss.fu-berlin.de/dblp/terms.rdf#	20111028
dbo	http://dbpedia.org/ontology/	20111028
dbp	http://dbpedia.org/property/	20111028
dbpedia	http://dbpedia.org/resource/	20111028
dbpediaowl	http://dbpedia.org/ontology/	20111028
dbpp	http://dbpedia.org/property/	20111028
dbpprop	http://dbpedia.org/property/	20111028
dbprop	http://dbpedia.org/property/	20111028
dbptmpl	http://dbpedia.org/resource/Template:	20111028
dbr	http://dbpedia.org/resource/	20111028
dc	http://purl.org/dc/elements/1.1/	20111028
dc11	http://purl.org/dc/elements/1.1/	20111028
dcam	http://purl.org/dc/dcam/	20111028
dcat	http://www.w3.org/ns/dcat#	20111028
dcmit	http://purl.org/dc/dcmitype/	20111028
dcmitype	http://purl.org/dc/dcmitype/	20111028
dcn	http://www.w3.org/2007/uwa/context/deliverycontext.owl#	20111028
dcq	http://purl.org/dc/terms/	20111028
dct	http://purl.org/dc/terms/	20111028
dcterm	http://purl.org/dc/terms/	20111028
dcterms	http://purl.org/dc/terms/	20111028
dctype	http://purl.org/dc/dcmitype/	20111028
ddc	http://purl.org/NET/decimalised#	20111028
ddl	http://purl.org/vocab/riro/ddl#	20111028
decl	http://www.linkedmodel.org/1.0/schema/decl#	20111028
derecho	http://purl.org/derecho#	20111028
dgfoaf	http://west.uni-koblenz.de/ontologies/2010/07/dgfoaf.owl#	20111028
dgtwc	http://data-gov.tw.rpi.edu/2009/data-gov-twc.rdf#	20111028
dir	http://schemas.talis.com/2005/dir/schema#	20111028
disease	http://www.agfa.com/w3c/2009/humanDisorder#	20111028
diseasome	http://www4.wiwiss.fu-berlin.de/diseasome/resource/diseasome/	20111028
dnr	http://www.dotnetrdf.org/configuration#	20111028
doac	http://ramonantonio.net/doac/0.1/#	20111028
doap	http://usefulinc.com/ns/doap#	20111028
doc	http://www.w3.org/2000/10/swap/pim/doc#	20111028
doclist	http://www.junkwork.net/xml/DocumentList#	20111028
drug	http://www.agfa.com/w3c/2009/drugTherapy#	20111028
drugbank	http://www4.wiwiss.fu-berlin.de/drugbank/resource/drugbank/	20111028
dtype	http://www.linkedmodel.org/schema/dtype#	20111028
dul	http://www.loa-cnr.it/ontologies/DUL.owl#	20111028
dummy	http://hello.com/	20111028
dv	http://rdf.data-vocabulary.org/#	20111028
ean	http://openean.kaufkauf.net/id/	20111028
earl	http://www.w3.org/ns/earl#	20111028
eat	http://www.awesomesauce.net/urmom/	20111028
eco	http://www.ebusiness-unibw.org/ontologies/eclass/5.1.4/#	20111028
ecs	http://rdf.ecs.soton.ac.uk/ontology/ecs#	20111028
edam	http://purl.bioontology.org/ontology/EDAM/	20111028
edm	http://www.europeana.eu/schemas/edm/	20111028
eg	http://eulergui.sourceforge.net/engine.owl#	20111028
elog	http://eulersharp.sourceforge.net/2003/03swap/log-rules#	20111028
enc	http://www.w3.org/2001/04/xmlenc#	20111028
environ	http://eulersharp.sourceforge.net/2003/03swap/environment#	20111028
es	http://eulersharp.sourceforge.net/2003/03swap/log-rules#	20111028
esd	http://def.esd.org.uk/	20111028
eu	http://eulersharp.sourceforge.net/2003/03swap/log-rules#	20111028
eui	http://institutions.publicdata.eu/#	20111028
event	http://purl.org/NET/c4dm/event.owl#	20111028
events	http://eulersharp.sourceforge.net/2003/03swap/event#	20111028
evopat	http://ns.aksw.org/Evolution/	20111028
evset	http://dsnotify.org/vocab/eventset/0.1/	20111028
ex	http://example.com/	20111028
exif	http://www.w3.org/2003/12/exif/ns#	20111028
eye	http://jena.hpl.hp.com/Eyeball#	20111028
ezcontext	http://ontologies.ezweb.morfeo-project.org/ezcontext/ns#	20111028
eztag	http://ontologies.ezweb.morfeo-project.org/eztag/ns#	20111028
fab	http://purl.org/fab/ns#	20111028
fabio	http://purl.org/spar/fabio#	20111028
factbook	http://www4.wiwiss.fu-berlin.de/factbook/ns#	20111028
fb	http://rdf.freebase.com/ns/	20111028
fc	http://www.freeclass.eu/freeclass_v1#	20111028
fct	http://openlinksw.com/services/facets/1.0/	20111028
fec	http://www.rdfabout.com/rdf/schema/usfec/	20111028
fed	http://www.openrdf.org/config/sail/federation#	20111028
fingal	http://vocab.deri.ie/fingal#	20111028
fn	http://www.w3.org/2005/xpath-functions#	20111028
foaf	http://xmlns.com/foaf/0.1/	20111028
formats	http://www.w3.org/ns/formats/	20111028
frbr	http://purl.org/vocab/frbr/core#	20111028
frbrcore	http://purl.org/vocab/frbr/core#	20111028
frbre	http://purl.org/vocab/frbr/extended#	20111028
freebase	http://rdf.freebase.com/ns/	20111028
fresnel	http://www.w3.org/2004/09/fresnel#	20111028
frir	http://purl.org/twc/ontology/frir.owl#	20111028
game	http://data.totl.net/game/	20111028
gazetteer	http://data.ordnancesurvey.co.uk/ontology/50kGazetteer/	20111028
gbv	http://purl.org/ontology/gbv/	20111028
gc	http://www.oegov.org/core/owl/gc#	20111028
gd	http://rdf.data-vocabulary.org/#	20111028
gelo	http://krauthammerlab.med.yale.edu/ontologies/gelo#	20111028
gen	http://www.w3.org/2006/gen/ont#	20111028
genab	http://eulersharp.sourceforge.net/2003/03swap/genomeAbnormality#	20111028
geo	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
geodata	http://sws.geonames.org/	20111028
geoes	http://geo.linkeddata.es/resource/	20111028
geographis	http://telegraphis.net/ontology/geography/geography#	20111028
geonames	http://www.geonames.org/ontology#	20111028
geospecies	http://rdf.geospecies.org/ont/geospecies#	20111028
geovocab	http://geovocab.org/	20111028
gesis	http://lod.gesis.org/lodpilot/ALLBUS/vocab.rdf#	20111028
giving	http://ontologi.es/giving#	20111028
gml	http://www.opengis.net/gml/	20111028
gn	http://www.geonames.org/ontology#	20111028
go	http://www.geneontology.org/go#	20111028
gob	http://purl.org/ontology/last-fm/	20111028
gold	http://purl.org/linguistics/gold/	20111028
govtrackus	http://www.rdfabout.com/rdf/usgov/geo/us/	20111028
govwild	http://govwild.org/ontology/GWOntology.owl#	20111028
gpt	http://purl.org/vocab/riro/gpt#	20111028
gr	http://purl.org/goodrelations/v1#	20111028
granatum	http://chem.deri.ie/granatum/	20111028
grddl	http://www.w3.org/2003/g/data-view#	20111028
greg	http://kasei.us/about/foaf.xrdf#	20111028
gridworks	http://purl.org/net/opmv/types/gridworks#	20111028
gv	http://rdf.data-vocabulary.org/#	20111028
h5	http://buzzword.org.uk/rdf/h5#	20111028
hard	http://www.w3.org/2007/uwa/context/hardware.owl#	20111028
harrisons	http://harrisons.cc/	20111028
hartigprov	http://purl.org/net/provenance/ns#	20111028
hcard	http://purl.org/uF/hCard/terms/	20111028
hcterms	http://purl.org/uF/hCard/terms/	20111028
healthcare	http://www.agfa.com/w3c/2009/healthCare#	20111028
hemogram	http://www.agfa.com/w3c/2009/hemogram#	20111028
hints2005	http://purl.org/twc/cabig/model/HINTS2005-1.owl#	20111028
hlisting	http://sindice.com/hlisting/0.1/	20111028
hospital	http://www.agfa.com/w3c/2009/hospital#	20111028
http	http://www.w3.org/2006/http#	20111028
httph	http://www.w3.org/2007/ont/httph#	20111028
httpvoc	http://www.w3.org/2006/http#	20111028
human	http://eulersharp.sourceforge.net/2003/03swap/human#	20111028
humanbody	http://eulersharp.sourceforge.net/2003/03swap/humanBody#	20111028
iao	http://purl.obolibrary.org/obo/iao.owl#	20111028
ibis	http://purl.org/ibis#	20111028
ical	http://www.w3.org/2002/12/cal/ical#	20111028
imm	http://schemas.microsoft.com/imm/	20111028
imreg	http://www.w3.org/2004/02/image-regions#	20111028
infection	http://www.agfa.com/w3c/2009/infectiousDisorder#	20111028
ir	http://www.ontologydesignpatterns.org/cp/owl/informationrealization.owl#	20111028
ire	http://www.ontologydesignpatterns.org/cpont/ire.owl#	20111028
iron	http://purl.org/ontology/iron#	20111028
irrl	http://www.ontologydesignpatterns.org/cp/owl/informationobjectsandrepresentationlanguages.owl#	20111028
irw	http://www.ontologydesignpatterns.org/ont/web/irw.owl#	20111028
is	http://purl.org/ontology/is/core#	20111028
isi	http://purl.org/ontology/is/inst/	20111028
isq	http://purl.org/ontology/is/quality/	20111028
ist	http://purl.org/ontology/is/types/	20111028
iswc	http://annotation.semanticweb.org/2004/iswc#	20111028
java	http://www.w3.org/2007/uwa/context/java.owl#	20111028
jdbc	http://d2rq.org/terms/jdbc/	20111028
kb	http://deductions.sf.net/ontology/knowledge_base.owl#	20111028
kontakt	http://richard.cyganiak.de/	20111028
kw	http://kwantu.net/kw/	20111028
kwijibo	http://kwijibo.talis.com/	20111028
label	http://purl.org/net/vocab/2004/03/label#	20111028
lang	http://ontologi.es/lang/core#	20111028
languages	http://eulersharp.sourceforge.net/2003/03swap/languages#	20111028
lark1	http://users.utcluj.ro/~raluca/ontology/Ontology1279614123500.owl#	20111028
lastfm	http://purl.org/ontology/last-fm/	20111028
ldap	http://purl.org/net/ldap/	20111028
lfm	http://purl.org/ontology/last-fm/	20111028
lfn	http://www.dotnetrdf.org/leviathan#	20111028
lgd	http://linkedgeodata.org/ontology/	20111028
lgdo	http://linkedgeodata.org/ontology/	20111028
lgv	http://linkedgeodata.org/ontology/	20111028
lib	http://schemas.talis.com/2005/library/schema#	20111028
lifecycle	http://purl.org/vocab/lifecycle/schema#	20111028
like	http://ontologi.es/like#	20111028
lingvoj	http://www.lingvoj.org/ontology#	20111028
link	http://www.w3.org/2006/link#	20111028
linkedct	http://data.linkedct.org/resource/linkedct/	20111028
linkedmdb	http://data.linkedmdb.org/sparql/	20111028
list	http://www.w3.org/2000/10/swap/list#	20111028
loc	http://www.w3.org/2007/uwa/context/location.owl#	20111028
lod2	http://lod2.eu/schema/	20111028
lodac	http://lod.ac/ns/lodac#	20111028
lode	http://linkedevents.org/ontology/	20111028
log	http://www.w3.org/2000/10/swap/log#	20111028
lom	http://ltsc.ieee.org/rdf/lomv1p0/lom#	20111028
lomvoc	http://ltsc.ieee.org/rdf/lomv1p0/vocabulary#	20111028
lotico	http://www.lotico.com/resource/	20111028
loticoowl	http://www.lotico.com/ontology/	20111028
lp	http://launchpad.net/rdf/launchpad#	20111028
lt	http://diplomski.nelakolundzija.org/LTontology.rdf#	20111028
lvont	http://lexvo.org/ontology#	20111028
lx	http://purl.org/NET/lx#	20111028
ma	http://www.w3.org/ns/ma-ont#	20111028
madsrdf	http://www.loc.gov/mads/rdf/v1#	20111028
malignneo	http://www.agfa.com/w3c/2009/malignantNeoplasm#	20111028
math	http://www.w3.org/2000/10/swap/math#	20111028
media	http://purl.org/media#	20111028
meetup	http://www.lotico.com/meetup/	20111028
mei	http://www.music-encoding.org/ns/mei/	20111028
memo	http://ontologies.smile.deri.ie/2009/02/27/memo#	20111028
meta	http://www.openrdf.org/rdf/2009/metadata#	20111028
meteo	http://purl.org/ns/meteo#	20111028
mf	http://poshrdf.org/ns/mf#	20111028
mit	http://purl.org/ontology/mo/mit#	20111028
mo	http://purl.org/ontology/mo/	20111028
moat	http://moat-project.org/ns#	20111028
money	http://purl.org/net/rdf-money/	20111028
movie	http://data.linkedmdb.org/resource/movie/	20111028
ms	http://purl.org/obo/owl/MS#	20111028
mte	http://nl.ijs.si/ME/owl/	20111028
mtecore	http://purl.org/olia/mte/multext-east.owl#	20111028
mu	http://www.kanzaki.com/ns/music#	20111028
muo	http://purl.oclc.org/NET/muo/muo#	20111028
music	http://musicontology.com/	20111028
musim	http://purl.org/ontology/similarity/	20111028
mygrid	http://www.mygrid.org.uk/ontology#	20111028
myspace	http://purl.org/ontology/myspace#	20111028
myspo	http://purl.org/ontology/myspace#	20111028
mysql	http://web-semantics.org/ns/mysql/	20111028
name	http://example.org/name#	20111028
nao	http://www.semanticdesktop.org/ontologies/2007/08/15/nao#	20111028
ncal	http://www.semanticdesktop.org/ontologies/2007/04/02/ncal#	20111028
nco	http://www.semanticdesktop.org/ontologies/2007/03/22/nco#	20111028
ne	http://umbel.org/umbel/ne/	20111028
net	http://www.w3.org/2007/uwa/context/network.owl#	20111028
nexif	http://www.semanticdesktop.org/ontologies/2007/05/10/nexif#	20111028
nfo	http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#	20111028
ngeo	http://geovocab.org/geometry#	20111028
nid3	http://www.semanticdesktop.org/ontologies/2007/05/10/nid3#	20111028
nie	http://www.semanticdesktop.org/ontologies/2007/01/19/nie#	20111028
nmo	http://www.semanticdesktop.org/ontologies/2007/03/22/nmo#	20111028
nndsr	http://semanticdiet.com/schema/usda/nndsr/	20111028
nocal	http://vocab.deri.ie/nocal#	20111028
nrl	http://www.semanticdesktop.org/ontologies/2007/08/15/nrl#	20111028
nsa	http://multimedialab.elis.ugent.be/organon/ontologies/ninsuna#	20111028
nt	http://ns.inria.fr/nicetag/2010/09/09/voc#	20111028
nuts	http://nuts.psi.enakting.org/id/BE335/doc/	20111028
nytimes	http://data.nytimes.com/elements/	20111028
oat	http://openlinksw.com/schemas/oat/	20111028
oauth	http://demiblog.org/vocab/oauth#	20111028
obj	http://www.openrdf.org/rdf/2009/object#	20111028
obo	http://purl.obolibrary.org/obo/	20111028
oboro	http://obofoundry.org/ro/ro.owl#	20111028
oboso	http://purl.org/obo/owl/SO#	20111028
oc	http://opencoinage.org/rdf/	20111028
odp	http://ontologydesignpatterns.org/	20111028
og	http://opengraphprotocol.org/schema/	20111028
ogp	http://ogp.me/ns#	20111028
ok	http://okkam.org/terms#	20111028
okkam	http://models.okkam.org/ENS-core-vocabulary#	20111028
olia	http://purl.org/olia/olia.owl#	20111028
olo	http://purl.org/ontology/olo/core#	20111028
omb	http://purl.org/ontomedia/ext/common/being#	20111028
omc	http://purl.org/ontomedia/ext/common/bestiary#	20111028
ome	http://purl.org/ontomedia/core/expression#	20111028
omm	http://purl.org/ontomedia/core/media#	20111028
omp	http://purl.org/ontomedia/ext/common/profession#	20111028
omt	http://purl.org/ontomedia/ext/common/trait#	20111028
oo	http://purl.org/openorg/	20111028
openlinks	http://www.openlinksw.com/schemas/virtrdf#	20111028
opensearch	http://a9.com/-/spec/opensearch/1.1/	20111028
oper	http://sweet.jpl.nasa.gov/2.0/mathOperation.owl#	20111028
opm	http://openprovenance.org/ontology#	20111028
opmv	http://purl.org/net/opmv/ns#	20111028
opo	http://online-presence.net/opo/ns#	20111028
opus	http://lsdis.cs.uga.edu/projects/semdis/opus#	20111028
opwn	http://www.ontologyportal.org/WordNet.owl#	20111028
ore	http://www.openarchives.org/ore/terms/	20111028
org	http://www.w3.org/ns/org#	20111028
organism	http://eulersharp.sourceforge.net/2003/03swap/organism#	20111028
organiz	http://eulersharp.sourceforge.net/2003/03swap/organization#	20111028
os	http://www.w3.org/2000/10/swap/os#	20111028
osag	http://www.ordnancesurvey.co.uk/ontology/AdministrativeGeography/v2.0/AdministrativeGeography.rdf#	20111028
osgb	http://data.ordnancesurvey.co.uk/id/	20111028
osoc	http://web-semantics.org/ns/opensocial#	20111028
osukdt	http://www.ordnancesurvey.co.uk/ontology/Datatypes.owl#	20111028
out	http://ontologies.hypios.com/out#	20111028
ov	http://open.vocab.org/terms/	20111028
overheid	http://standaarden.overheid.nl/owms/	20111028
owl	http://www.w3.org/2002/07/owl#	20111028
owlim	http://www.ontotext.com/trree/owlim#	20111028
owls	http://www.daml.org/services/owl-s/1.2/Service.owl#	20111028
owlse	http://www.daml.org/services/owl-s/1.2/generic/Expression.owl#	20111028
p20	http://zbw.eu/beta/p20/vocab/	20111028
p3p	http://www.w3.org/2002/01/p3prdfv1#	20111028
payment	http://reference.data.gov.uk/def/payment#	20111028
pbo	http://purl.org/ontology/pbo/core#	20111028
pc	http://purl.org/opendata-cz/public-contracts#	20111028
pdo	http://ontologies.smile.deri.ie/pdo#	20111028
pgterms	http://www.gutenberg.org/2009/pgterms/	20111028
phil	http://philosurfical.open.ac.uk/ontology/philosurfical.owl/	20111028
phss	http://ns.poundhill.com/phss/1.0/	20111028
pimo	http://www.semanticdesktop.org/ontologies/2007/11/01/pimo#	20111028
ping	http://purl.org/net/pingback/	20111028
place	http://purl.org/ontology/places/	20111028
play	http://uriplay.org/spec/ontology/#	20111028
plink	http://buzzword.org.uk/rdf/personal-link-types#	20111028
pmlj	http://inference-web.org/2.0/pml-justification.owl#	20111028
pmlp	http://inference-web.org/2.0/pml-provenance.owl#	20111028
pmlr	http://inference-web.org/2.0/pml-relation.owl#	20111028
pmlt	http://inference-web.org/2.0/pml-trust.owl#	20111028
pmt	http://tipsy.googlecode.com/svn/trunk/vocab/pmt#	20111028
pns	http://data.press.net/ontology/stuff/	20111028
po	http://purl.org/ontology/po/	20111028
pobo	http://purl.obolibrary.org/obo/	20111028
pois	http://purl.oclc.org/POIS/vcblr#	20111028
politico	http://www.rdfabout.com/rdf/schema/politico/	20111028
pom	http://maven.apache.org/POM/4.0.0#	20111028
pos	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
posh	http://poshrdf.org/ns/posh/	20111028
postcode	http://data.ordnancesurvey.co.uk/id/postcodeunit/	20111028
powder	http://www.w3.org/2007/05/powder#	20111028
ppo	http://vocab.deri.ie/ppo#	20111028
pr	http://ontologi.es/profiling#	20111028
prism	http://prismstandard.org/namespaces/1.2/basic/	20111028
prissma	http://ns.inria.fr/prissma/v1#	20111028
prj	http://purl.org/stuff/project/	20111028
product	http://purl.org/commerce/product#	20111028
profiling	http://ontologi.es/profiling#	20111028
prog	http://purl.org/prog/	20111028
prot	http://www.proteinontology.info/po.owl#	20111028
protege	http://protege.stanford.edu/system#	20111028
protons	http://proton.semanticweb.org/2005/04/protons#	20111028
prov	http://dvcs.w3.org/hg/prov/raw-file/tip/ontology/ProvenanceOntology.owl#	20111028
provenir	http://knoesis.wright.edu/provenir/provenir.owl#	20111028
prv	http://purl.org/net/provenance/ns#	20111028
prvr	http://purl.org/ontology/prv/rules#	20111028
prvtypes	http://purl.org/net/provenance/types#	20111028
ps	http://purl.org/payswarm#	20111028
psh	http://psh.techlib.cz/skos/	20111028
psych	http://purl.org/vocab/psychometric-profile/	20111028
pto	http://www.productontology.org/id/	20111028
ptr	http://www.w3.org/2009/pointers#	20111028
puc	http://purl.org/NET/puc#	20111028
puelia	http://kwijibo.talis.com/vocabs/puelia#	20111028
push	http://www.w3.org/2007/uwa/context/push.owl#	20111028
qb	http://purl.org/linked-data/cube#	20111028
qdoslf	http://foaf.qdos.com/lastfm/schema/	20111028
quak	http://dev.w3.org/cvsweb/2000/quacken/vocab#	20111028
quantities	http://eulersharp.sourceforge.net/2003/03swap/quantitiesExtension#	20111028
qudt	http://qudt.org/1.1/schema/qudt#	20111028
r2r	http://www4.wiwiss.fu-berlin.de/bizer/r2r/	20111028
rail	http://ontologi.es/rail/vocab#	20111028
rdacarrier	http://rdvocab.info/termList/RDACarrierType/	20111028
rdacontent	http://rdvocab.info/termList/RDAContentType/	20111028
rdamedia	http://rdvocab.info/termList/RDAMediaType/	20111028
rdb	http://www.dbs.cs.uni-duesseldorf.de/RDF/relational#	20111028
rdf	http://www.w3.org/1999/02/22-rdf-syntax-ns#	20111028
rdfa	http://www.w3.org/ns/rdfa#	20111028
rdfdata	http://rdf.data-vocabulary.org/rdf.xml#	20111028
rdfdf	http://www.openlinksw.com/virtrdf-data-formats#	20111028
rdfg	http://www.w3.org/2004/03/trix/rdfg-1/	20111028
rdfs	http://www.w3.org/2000/01/rdf-schema#	20111028
rdo	http://purl.org/rdo/ns#	20111028
re	http://www.w3.org/2000/10/swap/reason#	20111028
rec	http://purl.org/ontology/rec/core#	20111028
reco	http://purl.org/reco#	20111028
ref	http://purl.org/vocab/relationship/	20111028
rei	http://www.w3.org/2004/06/rei#	20111028
rel	http://purl.org/vocab/relationship/	20111028
remus	http://www.semanticweb.org/ontologies/2010/6/Ontology1279614123500.owl#	20111028
rep	http://www.openrdf.org/config/repository#	20111028
req	http://ns.softwiki.de/req/	20111028
res	http://www.w3.org/2005/sparql-results#	20111028
resex	http://resex.rkbexplorer.com/ontologies/resex#	20111028
resist	http://www.rkbexplorer.com/ontologies/resist#	20111028
resource	http://purl.org/vocab/resourcelist/schema#	20111028
rev	http://purl.org/stuff/rev#	20111028
rich	http://rdf.data-vocabulary.org/	20111028
rif	http://www.w3.org/2007/rif#	20111028
rnews	http://iptc.org/std/rNews/2011-10-07#	20111028
ro	http://purl.org/obo/owl/ro#	20111028
room	http://vocab.deri.ie/rooms#	20111028
rooms	http://vocab.deri.ie/rooms#	20111028
rpubl	http://rinfo.lagrummet.se/ns/2008/11/rinfo/publ#	20111028
rr	http://www.w3.org/ns/r2rml#	20111028
rsa	http://www.w3.org/ns/auth/rsa#	20111028
rss	http://purl.org/rss/1.0/	20111028
rulz	http://purl.org/NET/rulz#	20111028
rv	http://wifo-ravensburg.de/semanticweb.rdf#	20111028
s2s	http://escience.rpi.edu/ontology/sesf/s2s/2/0/	20111028
s3db	http://www.s3db.org/core#	20111028
s4ac	http://ns.inria.fr/s4ac/v1#	20111028
sail	http://www.openrdf.org/config/sail#	20111028
sawsdl	http://www.w3.org/ns/sawsdl#	20111028
saxon	http://saxon.sf.net/	20111028
sc	http://umbel.org/umbel/sc/	20111028
schema	http://schema.org/	20111028
sco	http://purl.org/ontology/sco#	20111028
scot	http://scot-project.org/scot/ns#	20111028
scovo	http://purl.org/NET/scovo#	20111028
scowt	http://purl.org/weso/ontologies/scowt#	20111028
scsv	http://purl.org/NET/schema-org-csv#	20111028
scv	http://purl.org/NET/scovo#	20111028
sd	http://www.w3.org/ns/sparql-service-description#	20111028
sdl	http://purl.org/vocab/riro/sdl#	20111028
sdmx	http://purl.org/linked-data/sdmx#	20111028
sdmxdim	http://purl.org/linked-data/sdmx/2009/dimension#	20111028
search	http://sindice.com/vocab/search#	20111028
sec	http://purl.org/security#	20111028
sede	http://eventography.org/sede/0.1/	20111028
semtweet	http://semantictweet.com/	20111028
sesame	http://www.openrdf.org/schema/sesame#	20111028
session	http://redfoot.net/2005/session#	20111028
shv	http://ns.aksw.org/spatialHierarchy/	20111028
sider	http://www4.wiwiss.fu-berlin.de/sider/resource/sider/	20111028
sig	http://purl.org/signature#	20111028
sim	http://purl.org/ontology/similarity/	20111028
sindice	http://vocab.sindice.net/	20111028
sio	http://semanticscience.org/resource/	20111028
sioc	http://rdfs.org/sioc/ns#	20111028
sioca	http://rdfs.org/sioc/actions#	20111028
sioct	http://rdfs.org/sioc/types#	20111028
sioctypes	http://rdfs.org/sioc/types#	20111028
sism	http://purl.oclc.org/NET/sism/0.1/	20111028
sit	http://www.ontologydesignpatterns.org/cp/owl/situation.owl#	20111028
skip	http://skipforward.net/skipforward/resource/	20111028
skiresort	http://www.openlinksw.com/ski_resorts/schema#	20111028
skos	http://www.w3.org/2004/02/skos/core#	20111028
skosxl	http://www.w3.org/2008/05/skos-xl#	20111028
sl	http://www.semanlink.net/2001/00/semanlink-schema#	20111028
sm	http://topbraid.org/sparqlmotion#	20111028
smf	http://topbraid.org/sparqlmotionfunctions#	20111028
smiley	http://www.smileyontology.com/ns#	20111028
sml	http://topbraid.org/sparqlmotionlib#	20111028
so	http://purl.org/ontology/symbolic-music/	20111028
soap	http://www.w3.org/2003/05/soap-envelope/	20111028
soft	http://www.w3.org/2007/uwa/context/software.owl#	20111028
sp	http://spinrdf.org/sp#	20111028
space	http://purl.org/net/schemas/space/	20111028
spacerel	http://data.ordnancesurvey.co.uk/ontology/spatialrelations/	20111028
span	http://www.ifomis.org/bfo/1.1/span#	20111028
sparql	http://www.openrdf.org/config/repository/sparql#	20111028
spatial	http://geovocab.org/spatial#	20111028
spc	http://purl.org/ontomedia/core/space#	20111028
spin	http://spinrdf.org/spin#	20111028
spl	http://spinrdf.org/spl#	20111028
sport	http://www.bbc.co.uk/ontologies/sport/	20111028
sr	http://www.openrdf.org/config/repository/sail#	20111028
sso	http://nlp2rdf.lod2.eu/schema/sso/	20111028
states	http://www.w3.org/2005/07/aaa#	20111028
status	http://ontologi.es/status#	20111028
steel	http://ontorule-project.eu/resources/steel-30#	20111028
str	http://nlp2rdf.lod2.eu/schema/string/	20111028
string	http://www.w3.org/2000/10/swap/string#	20111028
sv	http://schemas.talis.com/2005/service/schema#	20111028
swanag	http://purl.org/swan/1.2/agents/	20111028
swanci	http://purl.org/swan/1.2/citations/	20111028
swanco	http://purl.org/swan/1.2/swan-commons/	20111028
swande	http://purl.org/swan/1.2/discourse-elements/	20111028
swandr	http://purl.org/swan/1.2/discourse-relationships/	20111028
swanpav	http://purl.org/swan/1.2/pav/	20111028
swanq	http://purl.org/swan/1.2/qualifiers/	20111028
swanqs	http://purl.org/swan/1.2/qualifiers/	20111028
swc	http://data.semanticweb.org/ns/swc/ontology#	20111028
swh	http://plugin.org.uk/swh-plugins/	20111028
swid	http://semanticweb.org/id/	20111028
swivt	http://semantic-mediawiki.org/swivt/1.0#	20111028
swp	http://www.w3.org/2004/03/trix/swp-2/	20111028
swrc	http://swrc.ontoware.org/ontology#	20111028
swrl	http://www.w3.org/2003/11/swrl#	20111028
swrlb	http://www.w3.org/2003/11/swrlb#	20111028
sysont	http://ns.ontowiki.net/SysOnt/	20111028
tag	http://www.holygoat.co.uk/owl/redwood/0.1/tags/	20111028
tags	http://www.holygoat.co.uk/owl/redwood/0.1/tags/	20111028
tarot	http://data.totl.net/tarot/card/	20111028
taxo	http://purl.org/rss/1.0/modules/taxonomy/	20111028
tblcard	http://www.w3.org/People/Berners-Lee/card#	20111028
tdb	http://jena.hpl.hp.com/2008/tdb#	20111028
teach	http://linkedscience.org/teach/ns#	20111028
tei	http://www.tei-c.org/ns/1.0/	20111028
telix	http://purl.org/telix#	20111028
telmap	http://purl.org/telmap/	20111028
test	http://test2.example.com/	20111028
test2	http://this.invalid/test2#	20111028
theatre	http://purl.org/theatre#	20111028
ti	http://www.ontologydesignpatterns.org/cp/owl/timeinterval.owl#	20111028
time	http://www.w3.org/2006/time#	20111028
timeline	http://purl.org/NET/c4dm/timeline.owl#	20111028
tio	http://purl.org/tio/ns#	20111028
tl	http://purl.org/NET/c4dm/timeline.owl#	20111028
tmo	http://www.semanticdesktop.org/ontologies/2008/05/20/tmo#	20111028
tmpl	http://purl.org/restdesc/http-template#	20111028
toby	http://tobyinkster.co.uk/#	20111028
trackback	http://madskills.com/public/xml/rss/module/trackback/	20111028
transmed	http://www.w3.org/2001/sw/hcls/ns/transmed/	20111028
tripfs	http://purl.org/tripfs/2010/02#	20111028
tripfs2	http://purl.org/tripfs/2010/06#	20111028
ttl	http://www.w3.org/2008/turtle#	20111028
txn	http://lod.taxonconcept.org/ontology/txn.owl#	20111028
tzont	http://www.w3.org/2006/timezone#	20111028
ufmedia	http://purl.org/microformat/hmedia/	20111028
ui	http://www.w3.org/ns/ui#	20111028
umbel	http://umbel.org/umbel#	20111028
umbelrc	http://umbel.org/umbel/rc/	20111028
uni	http://purl.org/weso/uni/uni.html#	20111028
uniprot	http://purl.uniprot.org/core/	20111028
unit	http://qudt.org/vocab/unit#	20111028
units	http://eulersharp.sourceforge.net/2003/03swap/unitsExtension#	20111028
urn	http://fliqz.com/	20111028
user	http://schemas.talis.com/2005/user/schema#	20111028
usgov	http://www.rdfabout.com/rdf/schema/usgovt/	20111028
uta	http://uptheasset.org/ontology#	20111028
vaem	http://www.linkedmodel.org/schema/vaem#	20111028
vann	http://purl.org/vocab/vann/	20111028
vcard	http://www.w3.org/2006/vcard/ns#	20111028
vcard2006	http://www.w3.org/2006/vcard/ns#	20111028
vcardx	http://buzzword.org.uk/rdf/vcardx#	20111028
vdpp	http://data.lirmm.fr/ontologies/vdpp#	20111028
video	http://purl.org/media/video#	20111028
visko	http://trust.utep.edu/visko/ontology/visko-operator-v3.owl#	20111028
viskoo	http://trust.utep.edu/visko/ontology/visko-operator-v3.owl#	20111028
viskov	http://trust.utep.edu/visko/ontology/visko-view-v3.owl#	20111028
vitro	http://vitro.mannlib.cornell.edu/ns/vitro/public#	20111028
vivo	http://vivoweb.org/ontology/core#	20111028
voaf	http://mondeca.com/foaf/voaf#	20111028
voag	http://voag.linkedmodel.org/schema/voag#	20111028
void	http://rdfs.org/ns/void#	20111028
vote	http://www.rdfabout.com/rdf/schema/vote/	20111028
vs	http://www.w3.org/2003/06/sw-vocab-status/ns#	20111028
vso	http://purl.org/vso/ns#	20111028
vsto	http://escience.rpi.edu/ontology/vsto/2/0/vsto.owl#	20111028
w3con	http://www.w3.org/2000/10/swap/pim/contact#	20111028
w3p	http://prov4j.org/w3p/	20111028
wai	http://purl.org/wai#	20111028
wairole	http://www.w3.org/2005/01/wai-rdf/GUIRoleTaxonomy#	20111028
wao	http://webtlab.it.uc3m.es/2010/10/WebAppsOntology#	20111028
water	http://escience.rpi.edu/ontology/semanteco/2/0/water.owl#	20111028
wdr	http://www.w3.org/2007/05/powder#	20111028
wdrs	http://www.w3.org/2007/05/powder-s#	20111028
web	http://www.w3.org/2007/uwa/context/web.owl#	20111028
webtlab	http://webtlab.it.uc3m.es/	20111028
wf	http://www.w3.org/2005/01/wf/flow#	20111028
wgs	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
wgs84	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
wgspos	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
whois	http://www.kanzaki.com/ns/whois#	20111028
wisski	http://wiss-ki.eu/	20111028
wlp	http://weblab-project.org/core/model/property/processing/	20111028
wm	http://ns.inria.fr/webmarks#	20111028
wn	http://xmlns.com/wordnet/1.6/	20111028
wn20schema	http://www.w3.org/2006/03/wn/wn20/schema/	20111028
wnschema	http://www.cogsci.princeton.edu/~wn/schema/	20111028
wo	http://purl.org/ontology/wo/	20111028
wordmap	http://purl.org/net/ns/wordmap#	20111028
wordnet	http://purl.org/vocabularies/princeton/wordnet/schema#	20111028
wot	http://xmlns.com/wot/0.1/	20111028
wsc	http://www.openk.org/wscaim.owl#	20111028
wv	http://vocab.org/waiver/terms/	20111028
xbrli	http://www.xbrl.org/2003/instance#	20111028
xch	http://oanda2rdf.appspot.com/xch/	20111028
xds	http://www.w3.org/2001/XMLSchema#	20111028
xen	http://buzzword.org.uk/rdf/xen#	20111028
xesam	http://freedesktop.org/standards/xesam/1.0/core#	20111028
xf	http://www.w3.org/2002/xforms/	20111028
xfn	http://vocab.sindice.com/xfn#	20111028
xfnv	http://vocab.sindice.com/xfn#	20111028
xforms	http://www.w3.org/2002/xforms/	20111028
xhe	http://buzzword.org.uk/rdf/xhtml-elements#	20111028
xhtml	http://www.w3.org/1999/xhtml/vocab#	20111028
xhtmlvocab	http://www.w3.org/1999/xhtml/vocab/	20111028
xhv	http://www.w3.org/1999/xhtml/vocab#	20111028
xl	http://langegger.at/xlwrap/vocab#	20111028
xlink	http://www.w3.org/1999/xlink/	20111028
xro	http://www.stalsoft.com/ontologies/xro/ns#	20111028
xs	http://www.w3.org/2001/XMLSchema#	20111028
xsd	http://www.w3.org/2001/XMLSchema#	20111028
xsl	http://www.w3.org/1999/XSL/Transform#	20111028
xt	http://purl.org/twc/vocab/cross-topix#	20111028
xtypes	http://purl.org/xtypes/	20111028
ya	http://blogs.yandex.ru/schema/foaf/	20111028
yago	http://dbpedia.org/class/yago/	20111028
yoda	http://purl.org/NET/yoda#	20111028
zbwext	http://zbw.eu/namespaces/zbw-extensions/	20111028
zem	http://s.zemanta.com/ns#	20111028
zoology	http://purl.org/NET/biol/zoology#	20111028
daiaserv	http://purl.org/ontology/daia/service/	20111031
vvo	http://purl.org/vvo/ns#	20111031
vsw	http://verticalsearchworks.com/ontology/	20111102
commerce	http://search.yahoo.com/searchmonkey/commerce/	20111124
gnd	http://d-nb.info/gnd/	20111124
grs	http://www.georss.org/georss/	20111124
htir	http://www.w3.org/2011/http#	20111124
infosys	http://www.infosys.com/	20111124
muto	http://purl.org/muto/core#	20111124
omapi	http://purl.org/omapi/0.2/#	20111124
prf	http://www.openmobilealliance.org/tech/profiles/UAPROF/ccppschema-20021212#	20111124
webbox	http://webbox.ecs.soton.ac.uk/ns#	20111124
calli	http://callimachusproject.org/rdf/2009/framework#	20111208
dwc	http://rs.tdwg.org/dwc/terms/	20111208
eunis	http://eunis.eea.europa.eu/rdf/species-schema.rdf#	20111208
georss	http://www.georss.org/georss/	20111208
pna	http://data.press.net/ontology/asset/	20111208
swpatho	http://swpatho.ag-nbi.de/context/meta.owl#	20111208
voidp	http://www.enakting.org/provenance/voidp/	20111208
arecipe	http://purl.org/amicroformat/arecipe/	20120124
cis	http://purl.org/NET/cloudisus#	20120124
daiaserv	http://purl.org/ontology/daia/Service/	20120124
datafaqs	http://purl.org/twc/vocab/datafaqs#	20120124
db	http://dbpedia.org/	20120124
ends	http://labs.mondeca.com/vocab/endpointStatus#	20120124
identity	http://purl.org/twc/ontologies/identity.owl#	20120124
italy	http://data.kasabi.com/dataset/italy/schema/	20120124
jita	http://aims.fao.org/aos/jita/	20120124
media	http://search.yahoo.com/searchmonkey/media/	20120124
moby	http://www.mygrid.org.uk/mygrid-moby-service#	20120124
nfo	http://www.semanticdesktop.org/ontologies/nfo/#	20120124
np	http://www.nanopub.org/nschema#	20120124
ocd	http://dati.camera.it/ocd/	20120124
places	http://purl.org/ontology/places#	20120124
protegedc	http://protege.stanford.edu/plugins/owl/dc/protege-dc.owl#	20120124
transit	http://vocab.org/transit/terms/	20120124
vsr	http://purl.org/twc/vocab/vsr#	20120124
wfdesc	http://purl.org/wf4ever/wfdesc#	20120124
wikipedia	http://www.systemone.at/2006/03/wikipedia#	20120124
aerols	http://xmlns.com/aerols/0.1/	20120426
carfo	http://purl.org/carfo#	20120426
cerif	http://spi-fm.uca.es/neologism/cerif#	20120426
cheminf	http://www.semanticweb.org/ontologies/cheminf.owl#	20120426
cts2	http://schema.omg.org/spec/CTS2/1.0/	20120426
example	http://www.example.org/rdf#	20120426
func	http://www.w3.org/2007/rif-builtin-function#	20120426
geom	http://geovocab.org/geometry#	20120426
gldp	http://www.w3.org/ns/people#	20120426
goef	http://purl.org/twc/vocab/goef#	20120426
hg	http://www.holygoat.co.uk/owl/redwood/0.1/tags/	20120426
ipad	http://www.padinthecity.com/	20120426
isbd	http://iflastandards.info/ns/isbd/elements/	20120426
kupkb	http://www.e-lico.eu/data/kupkb/	20120426
lexvo	http://lexvo.org/ontology#	20120426
linkedct	http://data.linkedct.org/vocab/	20120426
lr	http://linkedrecipes.org/schema/	20120426
lv	http://lobid.org/vocab/lobid#	20120426
marcrel	http://id.loc.gov/vocabulary/relators/	20120426
metalex	http://www.metalex.eu/metalex/2008-05-02#	20120426
mohammad	http://manesht.ir/	20120426
nfo	http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#	20120426
npg	http://ns.nature.com/terms/	20120426
nsogi	http://prefix.cc/nsogi:	20120426
oac	http://www.openannotation.org/ns/	20120426
ogorg	http://opengraph.org/schema/	20120426
omv	http://omv.ontoware.org/2005/05/ontology#	20120426
onssprel	http://www.ordnancesurvey.co.uk/ontology/SpatialRelations/v0.2/SpatialRelations.owl#	20120426
ospost	http://data.ordnancesurvey.co.uk/ontology/postcode/	20120426
pay	http://purl.org/commerce/payment#	20120426
pc	http://purl.org/procurement/public-contracts#	20120426
pf	http://jena.hpl.hp.com/ARQ/property#	20120426
pne	http://data.press.net/ontology/event/	20120426
prism21	http://prismstandard.org/namespaces/basic/2.1/	20120426
pro	http://purl.org/hpi/patchr#	20120426
prov	http://www.w3.org/ns/prov#	20120426
prviv	http://purl.org/net/provenance/integrity#	20120426
ql	http://www.w3.org/2004/ql#	20120426
r2rml	http://www.w3.org/ns/r2rml#	20120426
rating	http://www.tvblob.com/ratings/#	20120426
recipe	http://linkedrecipes.org/schema/	20120426
scufl2	http://ns.taverna.org.uk/2010/scufl2#	20120426
ssn	http://www.w3.org/2005/Incubator/ssn/ssnx/ssn#	20120426
vapour	http://vapour.sourceforge.net/vocab.rdf#	20120426
vsws	http://verticalsearchworks.com/ontology/synset#	20120426
wbc	http://worldbank.270a.info/classification/	20120426
wbp	http://worldbank.270a.info/property/	20120426
wkd	http://schema.wolterskluwer.de/	20120426
wp	http://vocabularies.wikipathways.org/	20120426
wscaim	http://www.openk.org/wscaim.owl#	20120426
xhtml	http://www.w3.org/1999/xhtml#	20120426
xkos	http://purl.org/linked-data/xkos#	20120426
d2r	http://sites.wiwiss.fu-berlin.de/suhl/bizer/d2r-server/config.rdf#	20120521
efo	http://www.ebi.ac.uk/efo/	20120521
enhancer	http://stanbol.apache.org/ontology/enhancer/enhancer#	20120521
fcm	http://eulersharp.sourceforge.net/2006/02swap/fcm#	20120521
fise	http://fise.iks-project.eu/ontology/	20120521
fl	http://eulersharp.sourceforge.net/2003/03swap/fl-rules#	20120521
fls	http://lukasblaho.sk/football_league_schema#	20120521
oboe	http://ecoinformatics.org/oboe/oboe.1.0/oboe-core.owl#	20120521
pccz	http://purl.org/procurement/public-contracts-czech#	20120521
rdrel	http://rdvocab.info/RDARelationshipsWEMI/	20120521
rec54	http://www.w3.org/2001/02pd/rec54.rdf#	20120521
acco	http://purl.org/acco/ns#	20120827
acm	http://www.semanticweb.org/ontologies/2012/acm.owl#	20120827
admssw	http://purl.org/adms/sw/	20120827
aers	http://aers.data2semantics.org/resource/	20120827
arg	http://rdfs.org/sioc/argument#	20120827
br	http://purl.org/business-register#	20120827
cao	http://purl.org/makolab/caont/	20120827
cogs	http://vocab.deri.ie/cogs#	20120827
crm	http://erlangen-crm.org/current/	20120827
dive	http://scubadive.networld.to/dive.rdf#	20120827
dpl	http://dbpedialite.org/things/	20120827
eprints	http://eprints.org/ontology/	20120827
eumida	http://data.kasabi.com/dataset/eumida/terms/	20120827
germplasm	http://purl.org/germplasm/terms#	20120827
intervals	http://reference.data.gov.uk/def/intervals/	20120827
lctr	http://data.linkedct.org/vocab/resource/	20120827
lemon	http://www.monnet-project.eu/lemon#	20120827
library	http://purl.org/library/	20120827
life	http://life.deri.ie/schema/	20120827
marl	http://purl.org/marl/ns#	20120827
muni	http://purl.org/ontology/muni#	20120827
ncbitaxon	http://purl.org/obo/owl/NCBITaxon#	20120827
no	http://km.aifb.kit.edu/projects/numbers/number#	20120827
npgd	http://ns.nature.com/datasets/	20120827
npgg	http://ns.nature.com/graphs/	20120827
npgx	http://ns.nature.com/extensions/	20120827
open	http://open.vocab.org/terms/	20120827
pav	http://purl.org/pav/	20120827
pkmn	http://pokedex.dataincubator.org/pkm/	20120827
pml	http://provenanceweb.org/ns/pml#	20120827
poder	http://poderopedia.com/vocab/	20120827
pol	http://escience.rpi.edu/ontology/semanteco/2/0/pollution.owl#	20120827
prism	http://prismstandard.org/namespaces/basic/2.0/	20120827
prv	http://purl.org/ontology/prv/core#	20120827
r4ta	http://ns.inria.fr/ratio4ta/v1#	20120827
rda	http://rdvocab.info/elements/	20120827
rdagr1	http://rdvocab.info/Elements/	20120827
rssynd	http://web.resource.org/rss/1.0/modules/syndication/	20120827
s4ac	http://ns.inria.fr/s4ac/v2#	20120827
sdgp	http://stats.data-gov.ie/property/	20120827
set	http://www.w3.org/2000/10/swap/set#	20120827
sgv	http://www.w3.org/TR/SVG/	20120827
spif	http://spinrdf.org/spif#	20120827
tcga	http://purl.org/tcga/core#	20120827
mpeg7	http://rhizomik.net/ontologies/2005/03/Mpeg7-2001.owl#	20120829
myprefix	http://myprefix.org/	20120829
ngeoi	http://vocab.lenka.no/geo-deling#	20120829
okg	http://openknowledgegraph.org/ontology/	20120829
flow	http://www.w3.org/2005/01/wf/flow#	20120905
osmsemnet	http://spatial.ucd.ie/2012/08/osmsemnet/	20120905
wfprov	http://purl.org/wf4ever/wfprov#	20120905
category	http://dbpedia.org/resource/Category:	20120917
ero	http://purl.obolibrary.org/obo/	20120917
interval	http://reference.data.gov.uk/def/intervals/	20120917
